==> imuikit-1.0.1.20170902-sources.jar: com/xdja/im/uikit/IClient.java <==
package com.xdja.im.uikit;

import android.content.Context;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

import com.xdja.im.core.callback.AccountCallback;
import com.xdja.im.core.callback.NotificationCallback;
import com.xdja.im.core.callback.UnReadMessageCallback;
import com.xdja.im.core.model.account.AccountAction;
import com.xdja.im.core.model.message.TalkCustomBean;
import com.xdja.im.core.model.message.TalkNotifyBean;
import com.xdja.im.core.model.param.SessionParam;

/**
 * @Package: com.xdja.im.uikit
 * @Author: xdjaxa
 * @Creation: 2017-04-17 15:25
 * @Version V1.0
 * @Description: UIKit对外提供接口类
 */
public interface IClient {

    /**
     * uikit初始化
     *
     * @param context 上下文
     * @param options 初始化参数
     */
    void init(Context context, @Nullable UiKitOptions options);

    /**
     * 用户登录
     *
     * @param params 用户登录参数
     */
    void login(@NonNull UiKitParams params);

    /**
     * 用户退出登录
     *
     * @param flag
     */
    void logout(int flag);

    /**
     * sdk初始化
     *
     * @param context 全局上下文环境
     * @param params  初始化信息，非空 {@link UiKitParams}
     * @param options sdk配置信息{@link UiKitOptions},
     *                如果为空或者未设置，则使用默认配置项
     */
    void init(Context context, @NonNull UiKitParams params, @Nullable UiKitOptions options);

    /**
     * imsdk退出调用，释放相关资源信息
     *
     * @param flag 说明<br>
     *             flag = 1: 应用关闭，释放所有资源,不再接收消息 <br>
     *             flag = 0: 应用退出前台，ImSdkService后台运行，继续接收消息
     */
    void release(int flag);

    /**
     * 获取sdk配置信息
     *
     * @return 当前im模块的配置信息
     */
    UiKitOptions getOptions();

    /**
     * 发送一条文本通知消息到聊天界面
     *
     * @param sessionId   如果是群组，则是群ID；如果是单聊，则是会话ID
     * @param sessionType 0：群组 1：单聊
     * @param bean        消息实体
     */
    void sendNotifyTextMessage(String sessionId, int sessionType, TalkNotifyBean bean);

    /**
     * 发送自定义消息到聊天界面
     *
     * @param sessionId   如果是群组，则是群ID；如果是单聊，则是会话ID
     * @param sessionType 0：群组 1：单聊
     * @param bean        消息实体
     */
    void sendCustomTextMessage(String sessionId, int sessionType, TalkCustomBean bean);

    /**
     * 清除聊天会话中所有消息
     *
     * @param sessionId   如果是群组，则是群ID；如果是单聊，则是会话ID
     * @param sessionType 0：群组 1：单聊
     */
    void clearSessionData(String sessionId, int sessionType);

    /**
     * 清空消息列表
     */
    void clearAllSessionData();

    /**
     * 清除缓存数据
     */
    void clearAllCacheData();

    /**
     * 是否打开听筒模式
     *
     * @param sessionId   如果是群组，则是群ID；如果是单聊，则是会话ID
     * @param sessionType 0：群组 1：单聊
     * @param isOpen      {@code true} 打开听筒 {@code false} 关闭听筒
     */
    void setReceiveMode(String sessionId, int sessionType, boolean isOpen);

    /**
     * 会话免打扰模式<br/>
     * 聊天设置界面调用
     *
     * @param sessionId   如果是群组，则是群ID；如果是单聊，则是会话ID
     * @param sessionType 0：群组 1：单聊
     * @param isDisturb   {code{true}}：设置免打扰； {code{false}}：取消免打扰
     */
    void setNoDisturbMode(String sessionId, int sessionType, boolean isDisturb);

    /**
     * 会话置顶功能设置
     *
     * @param sessionId   如果是群组，则是群ID；如果是单聊，则是会话ID
     * @param sessionType 0：群组 1：单聊
     * @param isTop       {code{true}}：设置置顶； {code{false}}：取消置顶
     */
    void setSessionTop(String sessionId, int sessionType, boolean isTop);

    /**
     * 获取回话的配置信息功能
     *
     * @param sessionId   如果是群组，则是群ID；如果是单聊，则是会话ID
     * @param sessionType 0：群组 1：单聊
     * @return
     */
    SessionParam getSessionParam(String sessionId, int sessionType);

    /**
     * 联系人变更通知接口
     *
     * @param account 联系人：联系人账号;群组：群组ID
     * @param action  联系人变更动作{@link AccountAction}
     */
    void notifyAccountChanged(String account, AccountAction action);

    /**
     * 注册联系人回调接口，用于读取联系人信息
     *
     * @param callback 联系人回调接口
     */
    void registerAccountCallback(AccountCallback callback);

    /**
     * 注册通知消息回调接口，用于提示新消息通知
     *
     * @param callback 通知回调接口
     */
    void registerNotificationCallback(NotificationCallback callback);

    /**
     * 注册更新未读消息回调接口，提示未读消息数量
     *
     * @param callback 未读消息数量更新通知回调
     */
    void registerUnReadMessageCallback(UnReadMessageCallback callback);
}

==> imuikit-1.0.4.20171101-4-sources.jar: com/xdja/im/uikit/IClient.java <==
package com.xdja.im.uikit;

import android.content.Context;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

import com.xdja.im.core.callback.AccountCallback;
import com.xdja.im.core.callback.CommonCallback;
import com.xdja.im.core.callback.NotificationCallback;
import com.xdja.im.core.callback.OnChatSettingCallback;
import com.xdja.im.core.callback.UnReadMessageCallback;
import com.xdja.im.core.model.account.AccountAction;
import com.xdja.im.core.model.account.ActionDesc;
import com.xdja.im.core.model.account.GroupAction;
import com.xdja.im.core.model.message.TalkCustomBean;
import com.xdja.im.core.model.message.TalkNotifyBean;
import com.xdja.im.core.model.param.SessionParam;

/**
 * @Package: com.xdja.im.uikit
 * @Author: xdjaxa
 * @Creation: 2017-04-17 15:25
 * @Version V1.0
 * @Description: UIKit对外提供接口类
 */
public interface IClient {

    /**
     * uikit初始化
     *
     * @param context 上下文
     * @param options 初始化参数
     */
    void init(Context context, @Nullable UiKitOptions options);

    /**
     * sdk初始化
     *
     * @param context 全局上下文环境
     * @param params  初始化信息，非空 {@link UiKitParams}
     * @param options sdk配置信息{@link UiKitOptions},
     *                如果为空或者未设置，则使用默认配置项
     */
    void init(Context context, @NonNull UiKitParams params, @Nullable UiKitOptions options);

    /**
     * imsdk退出调用，释放相关资源信息
     *
     * @param flag 说明<br>
     *             flag = 1: 应用关闭，释放所有资源,不再接收消息 <br>
     *             flag = 0: 应用退出前台，ImSdkService后台运行，继续接收消息
     */
    void release(int flag);

    /**
     * 获取sdk配置信息
     *
     * @return 当前im模块的配置信息
     */
    UiKitOptions getOptions();

    /**
     * 发送一条文本通知消息到聊天界面
     *
     * @param sessionId   如果是群组，则是群ID；如果是单聊，则是会话ID
     * @param sessionType 0：群组 1：单聊
     * @param bean        消息实体
     */
    void sendNotifyTextMessage(String sessionId, int sessionType, TalkNotifyBean bean);

    /**
     * 发送自定义消息到聊天界面
     *
     * @param sessionId   如果是群组，则是群ID；如果是单聊，则是会话ID
     * @param sessionType 0：群组 1：单聊
     * @param bean        消息实体
     */
    void sendCustomTextMessage(String sessionId, int sessionType, TalkCustomBean bean);

    /**
     * 清除聊天会话中所有消息
     *
     * @param sessionId   如果是群组，则是群ID；如果是单聊，则是会话ID
     * @param sessionType 0：群组 1：单聊
     */
    void clearSessionData(String sessionId, int sessionType);

    /**
     * 清空消息列表
     */
    void clearAllSessionData();

    /**
     * 清除缓存数据
     */
    void clearAllCacheData();

    /**
     * 是否打开听筒模式
     *
     * @param sessionId   如果是群组，则是群ID；如果是单聊，则是会话ID
     * @param sessionType 0：群组 1：单聊
     * @param isOpen      {@code true} 打开听筒 {@code false} 关闭听筒
     */
    void setReceiveMode(String sessionId, int sessionType, boolean isOpen);

    /**
     * 会话免打扰模式<br/>
     * 聊天设置界面调用
     *
     * @param sessionId   如果是群组，则是群ID；如果是单聊，则是会话ID
     * @param sessionType 0：群组 1：单聊
     * @param isDisturb   {code{true}}：设置免打扰； {code{false}}：取消免打扰
     */
    void setNoDisturbMode(String sessionId, int sessionType, boolean isDisturb);

    /**
     * 会话置顶功能设置
     *
     * @param sessionId   如果是群组，则是群ID；如果是单聊，则是会话ID
     * @param sessionType 0：群组 1：单聊
     * @param isTop       {code{true}}：设置置顶； {code{false}}：取消置顶
     */
    void setSessionTop(String sessionId, int sessionType, boolean isTop);

    /**
     * 获取回话的配置信息功能
     *
     * @param sessionId   如果是群组，则是群ID；如果是单聊，则是会话ID
     * @param sessionType 0：群组 1：单聊
     * @return
     */
    SessionParam getSessionParam(String sessionId, int sessionType);

    /**
     * 联系人变更通知接口
     *
     * @param account 联系人账号
     * @param action  联系人变更动作{@link AccountAction}
     */
    void notifyAccountChanged(String account, AccountAction action);

    /**
     * 群组变更通知接口
     *
     * @param groupId    群组ID
     * @param action     联系人变更动作{@link GroupAction}
     * @param actionDesc 描述信息{@link ActionDesc}
     */
    void notifyGroupChanged(String groupId, GroupAction action, ActionDesc actionDesc);

    /**
     * 注册联系人回调接口，用于读取联系人信息
     *
     * @param callback 联系人回调接口
     */
    void registerAccountCallback(AccountCallback callback);

    /**
     * 注册通知消息回调接口，用于提示新消息通知
     *
     * @param callback 通知回调接口
     */
    void registerNotificationCallback(NotificationCallback callback);

    /**
     * 注册更新未读消息回调接口，提示未读消息数量
     *
     * @param callback 未读消息数量更新通知回调
     */
    void registerUnReadMessageCallback(UnReadMessageCallback callback);

    /**
     * 注册启动会话设置界面回调
     *
     * @param callback
     */
    void registerOpenChatSettingCallback(OnChatSettingCallback callback);

    /**
     * 注册需要通过上层调用的通用接口
     *
     * @param callback 未读消息数量更新通知回调
     */
    void registerCommonCallback(CommonCallback callback);
}
